.. module:: wwdtm.location

****************
Module: location
****************

This module provides objects that are used to retrieve locations, location
information and location recordings from a copy of the Wait Wait Don't Tell Me!
Stats database.

Location
========

.. autoclass:: wwdtm.location.Location
    :members:
    :inherited-members:

LocationRecordings
==================

.. autoclass:: wwdtm.location.LocationRecordings
    :members:
    :inherited-members:

LocationUtility
===============

.. autoclass:: wwdtm.location.LocationUtility
    :members:
    :inherited-members:
